@@ -1,13 +1,14 @@
 package Spreadsheet::Engine::Function::STDEV;
 
 use strict;
+use warnings;
 
 use base 'Spreadsheet::Engine::Function::VAR';
 
 sub result {
   my ($self, $A) = @_;
-  return [ 0, "e#DIV/0!" ] unless $A->{count} > 1;
-  return sqrt($self->SUPER::result($A));
+  return [ 0, 'e#DIV/0!' ] unless $A->{count} > 1;
+  return sqrt $self->SUPER::result($A);
 }
 
 1;
@@ -32,7 +33,7 @@ This returns the standard deviation.
 
 =head2 result
 
-We calculate as per Knuth "The Art of Computer Programming" Vol. 2
+We calculate as per Knuth 'The Art of Computer Programming" Vol. 2
 3rd edition, page 232
 
 =head1 HISTORY
@@ -50,7 +51,7 @@ All Rights Reserved.
 
 Portions (c) Copyright 2007 Tony Bowden
 
-=head1 LICENSE
+=head1 LICENCE
 
 The contents of this file are subject to the Artistic License 2.0;
 you may not use this file except in compliance with the License.
