@@ -1,12 +1,13 @@
 package Spreadsheet::Engine::Function::VARP;
 
 use strict;
+use warnings;
 
 use base 'Spreadsheet::Engine::Function::VAR';
 
 sub result {
   my ($self, $A) = @_;
-  return [ 0, "e#DIV/0!" ] unless $A->{count} > 1;
+  return [ 0, 'e#DIV/0!' ] unless $A->{count} > 1;
   return $A->{sk} / $A->{count};
 }
 
@@ -50,7 +51,7 @@ All Rights Reserved.
 
 Portions (c) Copyright 2007 Tony Bowden
 
-=head1 LICENSE
+=head1 LICENCE
 
 The contents of this file are subject to the Artistic License 2.0;
 you may not use this file except in compliance with the License.
